<?php
/*
Plugin Name: Date Exclusion
Plugin URI: http://www.dailyblogtips.com/date-exclusion-wordpress-plugin/
Description: Gives your blog a feeling of freshness by turning off the display of date information after a specified number of days or immediately after posting.  Exclusion of date information can be set by default in the plugin file and/or manually for each post.
Author: Stephen Ward
Version: 1.0
Author URI: http://www.projectparadox.com/
*/

/*  Copyright 2007 Stephen Ward

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// DEFAULT SETTINGS
// Set to 'yes' to exclude all date information by default; set to 'no' to deactivate
$exclude_date = 'no';

// Set to the default number of days after which date information should no longer be displayed; set as 0 to deactivate
$date_expires = 0;

// Add the names of any date-related functions you use in your templates
$deactivated_functions = array('the_date', 'the_time');


// DO NOT EDIT BELOW THIS LINE
add_action('loop_start', 'date_exclusion');

function date_exclusion(){

	// Only exclude dates from single posts
	if (is_single()){
		global $date_expires, $deactivated_functions, $exclude_date, $wp_query;

		// Override default settings with custom field data if it exists
		if ($exclude_date_meta = get_post_meta($wp_query->post->ID, 'exclude_date', true))
			$exclude_date = $exclude_date_meta;
		if ($date_expires_meta = get_post_meta($wp_query->post->ID, 'date_expires', true))
			$date_expires = $date_expires_meta;

		// Exclude dates arbitrarily
		if (strtolower($exclude_date) == 'yes'){
			foreach ($deactivated_functions as $deactivated_function)
				add_filter($deactivated_function, 'do_nothing');
		}

		// Exclude dates based on time to expiration
		else if ($date_expires > 0){
			$now = mktime();
			$expires = get_the_time('U') + ($date_expires * 86400);
			if ($now >= $expires){
				foreach ($deactivated_functions as $deactivated_function)
					add_filter($deactivated_function, 'do_nothing');
			}
		}
	}
}

function do_nothing(){}
?>